TypeArray

Trait TypeArray 

pub trait TypeArray: Sealed { }
The marker trait for type-level arrays of type-level numbers.

Someday, it may contain an associated constant to produce a runtime array, like the other marker traits here. However, that is blocked by this issue.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl TypeArray for ATerm

Source

impl<V, A> TypeArray for TArr<V, A>